@@ -7,6 +7,8 @@ length.ArAr <- function(x){ nrow(x$x) }
 #' @export
 length.PD <- function(x){ nrow(x$x) }
 #' @export
+length.ThPb <- function(x){ nrow(x$x) }
+#' @export
 length.KCa <- function(x){ nrow(x$x) }
 #' @export
 length.ThU <- function(x){ nrow(x$x) }
@@ -29,6 +31,8 @@ subset.PbPb <- function(x,subset,...){ subset_helper(x,subset,...) }
 #' @export
 subset.ArAr <- function(x,subset,...){ subset_helper(x,subset,...) }
 #' @export
+subset.ThPb <- function(x,subset,...){ subset_helper(x,subset,...) }
+#' @export
 subset.KCa <- function(x,subset,...){ subset_helper(x,subset,...) }
 #' @export
 subset.PD <- function(x,subset,...){ subset_helper(x,subset,...) }
