@@ -51,8 +51,8 @@
 #' 
 #' @param x a two column matrix of values (first column) and their
 #'     standard errors (second column) OR an object of class
-#'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{KCa}, \code{ReOs},
-#'     \code{SmNd}, \code{RbSr}, \code{LuHf}, \code{ThU},
+#'     \code{UPb}, \code{PbPb}, \code{ThPb}, \code{ArAr}, \code{KCa},
+#'     \code{ReOs}, \code{SmNd}, \code{RbSr}, \code{LuHf}, \code{ThU},
 #'     \code{fissiontracks} or \code{UThHe}
 #' @param random.effects if \code{TRUE}, computes the weighted mean
 #'     using a random effects model with two parameters: the mean and
@@ -289,9 +289,10 @@ weightedmean.PbPb <- function(x,random.effects=TRUE,
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
 #'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{40}}Ca/\eqn{^{44}}Ca,
-#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os, \eqn{^{230}}Th/\eqn{^{232}}Th or
-#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
+#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
+#'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os,
+#'     \eqn{^{230}}Th/\eqn{^{232}}Th, \eqn{^{176}}Hf/\eqn{^{177}}Hf or
+#'     \eqn{^{204}}Pb/\eqn{^{208}}Pb ratio from an isochron
 #'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
 #'     stored in \code{settings('iratio',...)}.
 #' @param detritus detrital \eqn{^{230}}Th correction (only applicable
@@ -362,6 +363,24 @@ weightedmean.KCa <- function(x,random.effects=TRUE,
 }
 #' @rdname weightedmean
 #' @export
+weightedmean.ThPb <- function(x,random.effects=TRUE,
+                              detect.outliers=TRUE,plot=TRUE, from=NA,
+                              to=NA,levels=NA,clabel="",
+                              rect.col=c("#00FF0080","#FF000080"),
+                              outlier.col="#00FFFF80",sigdig=2,
+                              alpha=0.05,exterr=TRUE,ranked=FALSE,
+                              i2i=TRUE,hide=NULL,omit=NULL,
+                              omit.col=NA,...){
+    weightedmean_helper(x,random.effects=random.effects,
+                        detect.outliers=detect.outliers,plot=plot,
+                        from=from,to=to,levels=levels,clabel=clabel,
+                        rect.col=rect.col,outlier.col=outlier.col,
+                        sigdig=sigdig, alpha=alpha,exterr=exterr,
+                        i2i=i2i,units='Ma',ranked=ranked,hide=hide,
+                        omit=omit,omit.col=omit.col,...)
+}
+#' @rdname weightedmean
+#' @export
 weightedmean.ReOs <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE, from=NA,
                               to=NA,levels=NA,clabel="",
