@@ -175,10 +175,10 @@ get.york.xy <- function(x,a,b){
 #' output. These can subsequently be used for York regression.
 #'
 #' @param x a five or six column matrix OR an object of class
-#'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{ThU}, \code{UThHe},
-#'     or \code{PD} (which includes objects of class \code{RbSr},
-#'     \code{SmNd}, \code{LuHf} and \code{ReOs}), generated by the
-#'     \code{read.data(...)} function
+#'     \code{UPb}, \code{PbPb}, \code{ThPb}, \code{ArAr}, \code{ThU},
+#'     \code{UThHe}, or \code{PD} (which includes objects of class
+#'     \code{RbSr}, \code{SmNd}, \code{LuHf} and \code{ReOs}),
+#'     generated by the \code{read.data(...)} function
 #' @param format one of
 #'
 #' \code{1} or \code{2}: \code{X}, \code{s[X]}, \code{Y}, \code{s[Y]},
@@ -221,34 +221,39 @@ data2york.default <- function(x,format=1,...){
 
 #' @param option one of
 #'
-#' \code{1}: Wetherill concordia ratios: \code{X=07/35}, \code{sX=s[07/35]},
-#'     \code{Y=06/38}, \code{sY=s[06/38]}, \code{rXY}.
+#' \code{1}: Wetherill concordia ratios: \code{X=07/35},
+#' \code{sX=s[07/35]}, \code{Y=06/38}, \code{sY=s[06/38]}, \code{rXY}.
 #'
-#' \code{2}: Tera-Wasserburg ratios: \code{X=38/06}, \code{sX=s[38/06]},
-#'     \code{Y=07/06}, \code{sY=s[07/06]}, \code{rho=rXY}.
+#' \code{2}: Tera-Wasserburg ratios: \code{X=38/06},
+#' \code{sX=s[38/06]}, \code{Y=07/06}, \code{sY=s[07/06]},
+#' \code{rho=rXY}.
 #'
-#' \code{3}: \code{X=04/06}, \code{sX=s[04/06]}, \code{Y=38/06},
-#'     \code{sY=s[38/06]}, \code{rho=rXY} (only valid if
-#'     \code{format=4,5} or \code{6}).
+#' \code{3}: \code{X=38/06}, \code{sX=s[38/06]}, \code{Y=04/06},
+#' \code{sY=s[04/06]}, \code{rho=rXY} (only valid if \code{x$format=4,5}
+#' or \code{6}).
 #'
-#' \code{4}: \code{X=04/07}, \code{sX=s[04/07]}, \code{Y=05/07},
-#'     \code{sY=s[35/07]}, \code{rho=rXY} (only valid if
-#'     \code{format=4,5} or \code{6}).
+#' \code{4}: \code{X=35/07}, \code{sX=s[35/07]}, \code{Y=04/07},
+#' \code{sY=s[04/07]}, \code{rho=rXY} (only valid if \code{x$format=4,5}
+#' or \code{6}).
 #'
-#' \code{5}: U-Th-Pb concordia ratios: \code{X=08/32}, \code{sX=s[08/32]},
-#'     \code{Y=06/38}, \code{sY=s[06/38]}, \code{rho=rXY} (only valid
-#'     if \code{format=7} or \code{8}).
+#' \code{5}: U-Th-Pb concordia ratios: \code{X=06/38},
+#' \code{sX=s[06/38]}, \code{Y=08/32}, \code{sY=s[08/32]},
+#' \code{rho=rXY} (only valid if \code{x$format=7}).
 #'
 #' \code{6}: \code{X=38/06}, \code{sX=s[38/06]}, \code{Y=08/06},
-#'     \code{sY=s[08/06]}, \code{rho=rXY} (only valid if
-#'     \code{format=7} or \code{8}).
+#' \code{sY=s[08/06]}, \code{rho=rXY} (only valid if \code{x$format=7}).
 #' 
 #' \code{7}: \code{X=38/06}, \code{sX=s[38/06]}, \code{Y=08/06},
-#'     \code{sY=s[08/06]}, \code{rho=rXY} (only valid if
-#'     \code{format=7} or \code{8}).
+#' \code{sY=s[08/06]}, \code{rho=rXY} (only valid if \code{x$format=7}).
+#' 
+#' \code{8}: \code{X=32/08}, \code{sX=s[32/08]}, \code{Y=06/08},
+#' \code{sY=s[06/08]}, \code{rho=rXY} (only valid if \code{x$format=7}).
 #'
-#' @param tt the age of the sample. This is only used if \code{x} has
-#'     class 7 or 8, in order to calculate the inherited
+#' \code{9}: \code{X=32/08}, \code{sX=s[32/08]}, \code{Y=07/08},
+#' \code{sY=s[07/08]}, \code{rho=rXY} (only valid if \code{x$format=7}).
+#'
+#' @param tt the age of the sample. This is only used if
+#'     \code{x$format=7}, in order to calculate the inherited
 #'     \eqn{{}^{208}}Pb/\eqn{{}^{232}}Th ratio.
 #'
 #' @rdname data2york
@@ -291,6 +296,16 @@ data2york.UPb <- function(x,option=1,tt=0,...){
             ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
             out[i,] <- data2york_UPb_helper(ir,i1='U235Pb207',i2='Pb208cPb207')
         }
+    } else if (option==8 && x$format==7){ # 06/08 vs. 32/08
+        for (i in 1:ns){
+            ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
+            out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb206cPb208')
+        }
+    } else if (option==9 && x$format==7){ # 07/08 vs. 32/08
+        for (i in 1:ns){
+            ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
+            out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb207cPb208')
+        }
     } else {
         stop('Incompatible input format and concordia type.')
     }
@@ -309,54 +324,58 @@ data2york_UPb_helper <- function(x,i1=1,i2=2){
 #'     ratios. \code{data2york} returns five columns \code{X},
 #'     \code{s[X]}, \code{Y}, \code{s[Y]} and \code{r[X,Y]}.
 #'
-#' If \code{inverse=FALSE}, then \code{X} =
-#'     \eqn{{}^{206}}Pb/\eqn{{}^{204}}Pb and \code{Y} =
-#'     \eqn{{}^{207}}Pb/\eqn{{}^{204}}Pb (if \code{x} has class
-#'     \code{PbPb}), or \code{X} = \eqn{{}^{39}}Ar/\eqn{{}^{36}}Ar and
-#'     \code{Y} = \eqn{{}^{40}}Ar/\eqn{{}^{36}}Ar (if \code{x} has
-#'     class \code{ArAr}), or \code{X} =
-#'     \eqn{{}^{40}}K/\eqn{{}^{44}}Ca and \code{Y} =
-#'     \eqn{{}^{40}}Ca/\eqn{{}^{44}}Ca (if \code{x} has class
-#'     \code{KCa}), or \code{X} = \eqn{{}^{87}}Rb/\eqn{{}^{86}}Sr and
-#'     \code{Y} = \eqn{{}^{87}}Sr/\eqn{{}^{86}}Sr (if \code{x} has
-#'     class \code{RbSr}), or \code{X} =
-#'     \eqn{{}^{147}}Sm/\eqn{{}^{144}}Nd and \code{Y} =
-#'     \eqn{{}^{143}}Nd/\eqn{{}^{144}}Nd (if \code{x} has class
-#'     \code{SmNd}), or \code{X} = \eqn{{}^{187}}Re/\eqn{{}^{188}}Os
-#'     and \code{Y} = \eqn{{}^{187}}Os/\eqn{{}^{188}}Os (if \code{x}
-#'     has class \code{ReOs}), or \code{X} =
-#'     \eqn{{}^{176}}Lu/\eqn{{}^{177}}Hf and \code{Y} =
-#'     \eqn{{}^{176}}Hf/\eqn{{}^{177}}Hf (if \code{x} has class
-#'     \code{LuHf}).
-#'
 #' If \code{inverse=TRUE}, then \code{X} =
-#'     \eqn{{}^{204}}Pb/\eqn{{}^{206}}Pb and \code{Y} =
-#'     \eqn{{}^{207}}Pb/\eqn{{}^{206}}Pb (if \code{x} has class
-#'     \code{PbPb}), or \code{X} = \eqn{{}^{39}}Ar/\eqn{{}^{40}}Ar and
-#'     \code{Y} = \eqn{{}^{36}}Ar/\eqn{{}^{40}}Ar (if \code{x} has
-#'     class \code{ArAr}), or \code{X} =
-#'     \eqn{{}^{40}}K/\eqn{{}^{40}}Ca and \code{Y} =
-#'     \eqn{{}^{44}}Ca/\eqn{{}^{40}}Ca (if \code{x} has class
-#'     \code{KCa}), or \code{X} = \eqn{{}^{87}}Rb/\eqn{{}^{87}}Sr and
-#'     \code{Y} = \eqn{{}^{86}}Sr/\eqn{{}^{87}}Sr (if \code{x} has
-#'     class \code{RbSr}), or \code{X} =
-#'     \eqn{{}^{147}}Sm/\eqn{{}^{143}}Nd and \code{Y} =
-#'     \eqn{{}^{144}}Nd/\eqn{{}^{143}}Nd (if \code{x} has class
-#'     \code{SmNd}), or \code{X} = \eqn{{}^{187}}Re/\eqn{{}^{187}}Os
-#'     and \code{Y} = \eqn{{}^{188}}Os/\eqn{{}^{187}}Os (if \code{x}
-#'     has class \code{ReOs}), or \code{X} =
-#'     \eqn{{}^{176}}Lu/\eqn{{}^{176}}Hf and \code{Y} =
-#'     \eqn{{}^{177}}Hf/\eqn{{}^{176}}Hf (if \code{x} has class
-#'     \code{LuHf}).
+#' \eqn{{}^{204}}Pb/\eqn{{}^{206}}Pb and \code{Y} =
+#' \eqn{{}^{207}}Pb/\eqn{{}^{206}}Pb (if \code{x} has class
+#' \code{PbPb}), or \code{X} = \eqn{{}^{232}}Th/\eqn{{}^{208}}Pb and
+#' \code{Y} = \eqn{{}^{204}}Pb/\eqn{{}^{208}}Pb (if \code{x} has class
+#' \code{ThPb}), or \code{X} = \eqn{{}^{39}}Ar/\eqn{{}^{40}}Ar and
+#' \code{Y} = \eqn{{}^{36}}Ar/\eqn{{}^{40}}Ar (if \code{x} has class
+#' \code{ArAr}), or \code{X} = \eqn{{}^{40}}K/\eqn{{}^{40}}Ca and
+#' \code{Y} = \eqn{{}^{44}}Ca/\eqn{{}^{40}}Ca (if \code{x} has class
+#' \code{KCa}), or \code{X} = \eqn{{}^{87}}Rb/\eqn{{}^{87}}Sr and
+#' \code{Y} = \eqn{{}^{86}}Sr/\eqn{{}^{87}}Sr (if \code{x} has class
+#' \code{RbSr}), or \code{X} = \eqn{{}^{147}}Sm/\eqn{{}^{143}}Nd and
+#' \code{Y} = \eqn{{}^{144}}Nd/\eqn{{}^{143}}Nd (if \code{x} has class
+#' \code{SmNd}), or \code{X} = \eqn{{}^{187}}Re/\eqn{{}^{187}}Os and
+#' \code{Y} = \eqn{{}^{188}}Os/\eqn{{}^{187}}Os (if \code{x} has class
+#' \code{ReOs}), or \code{X} = \eqn{{}^{176}}Lu/\eqn{{}^{176}}Hf and
+#' \code{Y} = \eqn{{}^{177}}Hf/\eqn{{}^{176}}Hf (if \code{x} has class
+#' \code{LuHf}).
+#' 
+#' If \code{inverse=FALSE}, then \code{X} =
+#' \eqn{{}^{206}}Pb/\eqn{{}^{204}}Pb and \code{Y} =
+#' \eqn{{}^{207}}Pb/\eqn{{}^{204}}Pb (if \code{x} has class
+#' \code{PbPb}), or \code{X} = \eqn{{}^{232}}Th/\eqn{{}^{204}}Pb and
+#' \code{Y} = \eqn{{}^{208}}Pb/\eqn{{}^{204}}Pb (if \code{x} has class
+#' \code{ThPb}), or \code{X} = \eqn{{}^{39}}Ar/\eqn{{}^{36}}Ar and
+#' \code{Y} = \eqn{{}^{40}}Ar/\eqn{{}^{36}}Ar (if \code{x} has class
+#' \code{ArAr}), or \code{X} = \eqn{{}^{40}}K/\eqn{{}^{44}}Ca and
+#' \code{Y} = \eqn{{}^{40}}Ca/\eqn{{}^{44}}Ca (if \code{x} has class
+#' \code{KCa}), or \code{X} = \eqn{{}^{87}}Rb/\eqn{{}^{86}}Sr and
+#' \code{Y} = \eqn{{}^{87}}Sr/\eqn{{}^{86}}Sr (if \code{x} has class
+#' \code{RbSr}), or \code{X} = \eqn{{}^{147}}Sm/\eqn{{}^{144}}Nd and
+#' \code{Y} = \eqn{{}^{143}}Nd/\eqn{{}^{144}}Nd (if \code{x} has class
+#' \code{SmNd}), or \code{X} = \eqn{{}^{187}}Re/\eqn{{}^{188}}Os and
+#' \code{Y} = \eqn{{}^{187}}Os/\eqn{{}^{188}}Os (if \code{x} has class
+#' \code{ReOs}), or \code{X} = \eqn{{}^{176}}Lu/\eqn{{}^{177}}Hf and
+#' \code{Y} = \eqn{{}^{176}}Hf/\eqn{{}^{177}}Hf (if \code{x} has class
+#' \code{LuHf}).
 #'
 #' @rdname data2york
 #' @export
 data2york.ArAr <- function(x,inverse=TRUE,...){
-    if (inverse)
-        out <- ArAr.inverse.ratios(x)
-    else
-        out <- ArAr.normal.ratios(x)
-    colnames(out) <- c('X','sX','Y','sY','rXY')
+    out <- data2york(x$x,format=x$format,...)
+    invert <- (inverse & x$format==1) | (!inverse & x$format%in%c(2,3))
+    if (invert) out <- normal2inverse(out)
+    out
+}
+#' @rdname data2york
+#' @export
+data2york.ThPb <- function(x,inverse=FALSE,...){
+    out <- data2york(x$x,format=x$format,...)
+    invert <- (inverse & x$format==1) | (!inverse & x$format%in%c(2,3))
+    if (invert) out <- normal2inverse(out)
     out
 }
 #' @rdname data2york
@@ -370,9 +389,13 @@ data2york.KCa <- function(x,inverse=FALSE,...){
 #' @rdname data2york
 #' @export
 data2york.PbPb <- function(x,inverse=TRUE,...){
-    if (inverse) out <- PbPb.inverse.ratios(x)
-    else out <- PbPb.normal.ratios(x)
-    colnames(out) <- c('X','sX','Y','sY','rXY')
+    out <- data2york(x$x,format=x$format,...)
+    invert <- (inverse & x$format%in%c(1,3)) | (!inverse & x$format==2)
+    if (invert){ # swap columns for normal2inverse function
+        out[,c('X','sX','Y','sY','rXY')] <- out[,c('Y','sY','X','sX','rXY')]
+        out <- normal2inverse(out)
+        out[,c('X','sX','Y','sY','rXY')] <- out[,c('Y','sY','X','sX','rXY')]
+    }
     out
 }
 
